<?php

/**
 * @file
 * Drush commands.
 */

/**
 * Implements hook_drush_command().
 */
function dcq_drush_command() {
  $items = array();

  $items['dcq-install'] = array(
    'description' => 'Install DCQ (Drupal Code Quality) git hooks.',
    'aliases' => array('dcq'),
    'bootstrap' => DRUSH_BOOTSTRAP_DRUSH,
    'options' => array(
      'force' => array(
        'description' => 'Overwrite existing pre-commit hook files.',
      ),
    ),
  );

  return $items;
}

/**
 * Implements hook_drush_help().
 */
function dcq_drush_help($section) {
  switch ($section) {
    case 'drush:dcq-install':
      return dt("Install the dcq (Drupal Code Quality) hooks in a git project. This command can be run from within any git directory.");
  }
}

/**
 * Drush command; Setup DCQ git commit hooks.
 *
 * @param string $project_name
 *   The name of the project to create.  A github repo must already exist.
 */
function drush_dcq_install() {
  $source_dir = dirname(realpath(__FILE__));
  $dest_dir = exec('git rev-parse --show-toplevel');

  if (empty($dest_dir)) {
    return drush_set_error('dcq-no-git', 'No git directory was found.');
  }

  if ($dest_dir) {
    $dest_dir .= '/.git/hooks';
    $files = array('pre-commit', 'pre-commit_dcq');

    // Check for existing pre-commit hook files.
    foreach ($files as $file) {
      $dest_file = "{$dest_dir}/{$file}";
      if (file_exists($dest_file)) {
        drush_set_error('dcq-file-exists', dt('File @file already exists.', array('@file' => $dest_file)));
      }
    }

    // Exit or notify the user if there are existing pre-commit hook files.
    if (drush_get_error()) {
      if (!drush_get_option('force')) {
        drush_print('Use --force to overwrite existing pre-commit hooks.');
        return FALSE;
      }
      else {
        drush_print('Overwriting existing pre-commit hooks.');
      }
    }

    // Copy the files from dcq into the .git/hooks directory.
    foreach ($files as $file) {
      copy("{$source_dir}/{$file}", "{$dest_dir}/{$file}");
      chmod("{$dest_dir}/{$file}", 0755);
    }
    drush_print(dt('Installed pre-commit hooks in @dir', array('@dir' => $dest_dir)));
  }
}
